# Copyright 2023 Weavers @ Eternal Loom. All rights reserved.
#
# Use of this software is governed by the license that can be
# found in LICENSE file in the source repository.

"""Smart Types (Smartypes) is a AI Integrated type system for modern applications.
"""
import logging

logger = logging.getLogger(__name__)


def main() -> None:
    """Entry point for the framework"""
    print("Not my type, or is it your's?")
